@@ -517,7 +517,7 @@ class DynamicSetting(object):
 
         if self.is_fallback and not self.fallback_allowed:
             reason = 'Fallback in use'
-        elif self.current_time > self.download_time + self.max_age:
+        elif not self.download_time is None and self.current_time > self.download_time + self.max_age:
             reason = 'Settings too old'
         else:
             healthy = True
