@@ -111,6 +111,7 @@ def getProfileClass(
         redis_client,
         django_profile_model,
         django_pointer_model,
+        django_connection_tuple,  # should contain (connection, connections) from django.db
         django_count_func,
         profile_ttl,
         profile_ttl_margin,
@@ -130,6 +131,7 @@ def getProfileClass(
                                                   new_user_detection_ttl=new_user_detection_ttl)
     cls.django_profile_model = django_profile_model
     cls.django_pointer_model = django_pointer_model
+    cls.django_connection_tuple = django_connection_tuple
     cls.django_count_func = django_count_func
     cls.profile_ttl = profile_ttl
     cls.profile_ttl_margin = profile_ttl_margin
